nbxmpp.bosh.KeyStack

Package nbxmpp :: Module bosh :: Class KeyStack |
[hide private]
[frames] | no frames]

# Class KeyStack

source code

Class implementing key sequences for BOSH messages

Instance Methods | [hide private]
__init__(self, count) | source code
reset(self) | source code
get(self) | source code

Method Details | [hide private]

### __init__(self, count) (Constructor) | source code

### reset(self) | source code

### get(self) | source code